Exception: HTMLPipeline::MissingDependencyError
- Inherits:
-
RuntimeError
- Object
- RuntimeError
- HTMLPipeline::MissingDependencyError
- Defined in:
- lib/html_pipeline.rb
Overview
HTML processing filters and utilities. This module includes a small framework for defining DOM based content filters and applying them to user provided content.
See HTMLPipeline::Filter for information on building filters.
Construct a Pipeline for running multiple HTML filters. A pipeline is created once
with one to many filters, and it then can be called many times over the course
of its lifetime with input.
filters - Array of Filter objects. Each must respond to call(doc, context). Filters are performed in the order provided. default_context - The default context hash. Values specified here will be merged into values from the each individual pipeline run. Can NOT be nil. Default: empty Hash. result_class - The default Class of the result object for individual calls. Default: Hash. Protip: Pass in a Struct to get some semblance of type safety.